Changelog
=========
All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog`_ and this project adheres to `Semantic Versioning`_.

.. _Keep a Changelog: http://keepachangelog.com/en/1.0.0/
.. _Semantic Versioning: http://semver.org/spec/v2.0.0.html

`Unreleased`_
-------------

`0.1.2`_ - 2018-06-17
Fixed
^^^^^
- README badge status

`0.1.1`_ - 2018-06-17
---------------------
Fixed
^^^^^
- Minor issues with build compilation

`0.1.0`_ - 2018-06-16
---------------------
Added
^^^^^
- Initial version

.. _Unreleased: https://github.com/JaredLGillespie/rerunme/compare/v0.1.2...HEAD
.. _0.1.2: https://github.com/JaredLGillespie/rerunme/releases/tag/v0.1.2
.. _0.1.1: https://github.com/JaredLGillespie/rerunme/releases/tag/v0.1.1
